from .glvq import GLVQ
from .deeplvq import DeepLVQ
from .gmlvq import GMLVQ
# from .knn import KNN
# from .lvq1 import LVQ1
from .lvqmln import LVQMLN
from .network import Network

__all__ = [
    'GLVQ',
    'DeepLVQ',
    'GMLVQ',
    # 'KNN',
    # 'LVQ1',
    'LVQMLN',
    'Network',
]
